Index: /branches/eam_branches/ipp-20111122/Ohana/src/libdvo/include/dvo.h
===================================================================
--- /branches/eam_branches/ipp-20111122/Ohana/src/libdvo/include/dvo.h	(revision 33128)
+++ /branches/eam_branches/ipp-20111122/Ohana/src/libdvo/include/dvo.h	(revision 33129)
@@ -95,34 +95,35 @@
 /* Image.code values -- these values are 32 bit (as of PS1_V1) */
 typedef enum {
-  ID_IMAGE_NEW          = 0x00000000,  /* no calibrations yet attempted */
-  ID_IMAGE_PHOTOM_NOCAL = 0x00000001,  /* user-set value used within relphot: ignore */
-  ID_IMAGE_PHOTOM_POOR  = 0x00000002,  /* relphot says image is bad (dMcal > limit) */
-  ID_IMAGE_PHOTOM_SKIP  = 0x00000004,  /* user-set value: assert that this image has bad photometry */
-  ID_IMAGE_PHOTOM_FEW   = 0x00000008,  /* currently too few measurements for photometry */
-  ID_IMAGE_ASTROM_NOCAL = 0x00000010,  /* user-set value used within relastro: ignore */
-  ID_IMAGE_ASTROM_POOR  = 0x00000020,  /* relastro says image is bad (dR,dD > limit) */
-  ID_IMAGE_ASTROM_FAIL  = 0x00000040,  /* relastro fit diverged, fit not applied */
-  ID_IMAGE_ASTROM_SKIP  = 0x00000080,  /* user-set value: assert that this image has bad astrometry */
-  ID_IMAGE_ASTROM_FEW   = 0x00000100,  /* currently too few measurements for astrometry */
+  ID_IMAGE_NEW            = 0x00000000,  /* no calibrations yet attempted */
+  ID_IMAGE_PHOTOM_NOCAL   = 0x00000001,  /* user-set value used within relphot: ignore */
+  ID_IMAGE_PHOTOM_POOR    = 0x00000002,  /* relphot says image is bad (dMcal > limit) */
+  ID_IMAGE_PHOTOM_SKIP    = 0x00000004,  /* user-set value: assert that this image has bad photometry */
+  ID_IMAGE_PHOTOM_FEW     = 0x00000008,  /* currently too few measurements for photometry */
+  ID_IMAGE_ASTROM_NOCAL   = 0x00000010,  /* user-set value used within relastro: ignore */
+  ID_IMAGE_ASTROM_POOR    = 0x00000020,  /* relastro says image is bad (dR,dD > limit) */
+  ID_IMAGE_ASTROM_FAIL    = 0x00000040,  /* relastro fit diverged, fit not applied */
+  ID_IMAGE_ASTROM_SKIP    = 0x00000080,  /* user-set value: assert that this image has bad astrometry */
+  ID_IMAGE_ASTROM_FEW     = 0x00000100,  /* currently too few measurements for astrometry */
+  ID_IMAGE_PHOTOM_UBERCAL = 0x00000200,  /* externally-supplied photometry zero point from ubercal analysis */
 } DVOImageFlags;
 
 /* Measure.flags values -- these values are 32 bit (as of PS1_V1) */
 typedef enum {
-  ID_MEAS_NOCAL        = 0x00000001,  // detection ignored for this analysis (photcode, time range) -- internal only 
-  ID_MEAS_POOR_PHOTOM  = 0x00000002,  // detection is photometry outlier					     	  
-  ID_MEAS_SKIP_PHOTOM  = 0x00000004,  // detection was ignored for photometry measurement			     	  
-  ID_MEAS_AREA         = 0x00000008,  // detection near image edge						     
-  ID_MEAS_POOR_ASTROM  = 0x00000010,  // detection is astrometry outlier					     	  
-  ID_MEAS_SKIP_ASTROM  = 0x00000020,  // detection was ignored for astrometry measurement			     	  
-  ID_MEAS_USED_OBJ     = 0x00000040,  // detection was used during opdate objects				     
-  ID_MEAS_USED_CHIP    = 0x00000080,  // detection was used during update chips					     
-  ID_MEAS_BLEND_MEAS   = 0x00000100,  // detection is within radius of multiple objects				     
-  ID_MEAS_BLEND_OBJ    = 0x00000200,  // multiple detections within radius of object				     
-  ID_MEAS_UNDEF_3      = 0x00000400,  // unused									     
-  ID_MEAS_UNDEF_4      = 0x00000800,  // unused									     
-  ID_MEAS_BLEND_MEAS_X = 0x00001000,  // detection is within radius of multiple objects across catalogs		     
-  ID_MEAS_ARTIFACT     = 0x00002000,  // detection is thought to be non-astronomical				     
-  ID_MEAS_UNDEF_5      = 0x00004000,  // unused									     
-  ID_MEAS_UNDEF_6      = 0x00008000,  // unused									     
+  ID_MEAS_NOCAL          = 0x00000001,  // detection ignored for this analysis (photcode, time range) -- internal only 
+  ID_MEAS_POOR_PHOTOM    = 0x00000002,  // detection is photometry outlier					     	  
+  ID_MEAS_SKIP_PHOTOM    = 0x00000004,  // detection was ignored for photometry measurement			     	  
+  ID_MEAS_AREA           = 0x00000008,  // detection near image edge						     
+  ID_MEAS_POOR_ASTROM    = 0x00000010,  // detection is astrometry outlier					     	  
+  ID_MEAS_SKIP_ASTROM    = 0x00000020,  // detection was ignored for astrometry measurement			     	  
+  ID_MEAS_USED_OBJ       = 0x00000040,  // detection was used during opdate objects 
+  ID_MEAS_USED_CHIP      = 0x00000080,  // detection was used during update chips 
+  ID_MEAS_BLEND_MEAS     = 0x00000100,  // detection is within radius of multiple objects 
+  ID_MEAS_BLEND_OBJ      = 0x00000200,  // multiple detections within radius of object 
+  ID_MEAS_UNDEF_3        = 0x00000400,  // unused 
+  ID_MEAS_UNDEF_4        = 0x00000800,  // unused 
+  ID_MEAS_BLEND_MEAS_X   = 0x00001000,  // detection is within radius of multiple objects across catalogs		     
+  ID_MEAS_ARTIFACT       = 0x00002000,  // detection is thought to be non-astronomical				     
+  ID_MEAS_UNDEF_5        = 0x00004000,  // unused 
+  ID_MEAS_PHOTOM_UBERCAL = 0x00008000,  // externally-supplied zero point from ubercal analysis
 } DVOMeasureFlags;
 
@@ -206,10 +207,13 @@
 
 typedef struct {
-    off_t Nimage;
-    FlatCorrectionImage *image;
-    off_t Ncorr;
-    int *IDtoSeq;
-    FlatCorrection *corr;
-    float ***offset; // the correction images represented as a set of arrays (same sequence as *image)
+  off_t Nimage;
+  FlatCorrectionImage *image;
+  off_t Ncorr;
+  int *IDtoSeq;
+  FlatCorrection *corr;
+  float ***offset; // the correction images represented as a set of arrays (same sequence as *image)
+  int Nseason;
+  e_time *tstart;
+  e_time *tstop;
 } FlatCorrectionTable;
 
